@@ -20,9 +20,16 @@ def forside(self):
     }
 
     for tr in soup.find("div", {"id": "s_m_Content_Content_aktueltIsland_pa"}).find_all("tr", {"class": "DashWithScroll textTop"}):
+        content = tr.find("td", {"class": "infoCol"})
+        contentStr = str(content)
+        for span in content.find_all("span", {"class": "bb_b"}):
+            new = copy.copy(span)
+            new.name = "strong"
+            contentStr = contentStr.replace(str(span), str(new))
+
         forsideDict["aktuelt"].append({
             "punkt_farve": colorDict[tr.find("td", {"class": "iconCol"}).find("img").get("src").split("/")[-1]],
-            "text": markdownify.markdownify(str(tr.find("td", {"class": "infoCol"}).find("span")), heading_style="ATX").lstrip().rstrip().replace("\n\n", "\n"), #HTML til markdown det
+            "text": markdownify.markdownify(contentStr, heading_style="ATX").lstrip().rstrip().replace("\n\n", "\n"), #HTML til markdown det
         })
 
 
